@@ -1,8 +1,7 @@
 import json
-from wpwatcher.core import WPWatcher
 
-WP_SITES=[ WPWatcher.format_site(s) for s in [ {"url":"exemple.com"},
-              {"url":"exemple2.com"}  ] ]
+WP_SITES=[ {"url":"exemple.com"},
+              {"url":"exemple2.com"}  ]
 
 DEFAULT_CONFIG="""
 [wpwatcher]
@@ -10,4 +9,4 @@ wp_sites=%s
 smtp_server=localhost:1025
 from_email=testing-wpwatcher@exemple.com
 email_to=["test@mail.com"]
-"""%json.dumps(WP_SITES)
\ No newline at end of file
+"""%json.dumps(WP_SITES)
