@@ -73,8 +73,14 @@ class Scanner:
             os.makedirs(os.path.join(self.wpscan_output_folder, "info/"), exist_ok=True)
 
         self.syslog: Optional[SyslogOutput] = None
+        self.broken_syslog = False
         if conf["syslog_server"]:
-            self.syslog = SyslogOutput(conf)
+            try:
+                self.syslog = SyslogOutput(conf)
+            except Exception as e:
+                self.broken_syslog = True
+                log.error(f"Broken Syslog: {e}\n{traceback.format_exc()}")
+                
         
 
     def interrupt(self) -> None:
@@ -251,7 +257,9 @@ class Scanner:
             # Notify recepients if match triggers
             if self.mail.notify(
                 wp_site, wp_report, 
-                last_wp_report, wpscan_command=wpscan_command
+                last_wp_report, 
+                wpscan_command=wpscan_command,
+                wpscan_version=self.wpscan._wpscan_version or '??',
             ):
                 # Store report time
                 wp_report["last_email"] = wp_report["datetime"]
